Agent skill

Skip Triton Ascend Padding Fill

by Krusty84 in Krusty84/triton-ascend-agent-dev-kit

Use Triton-Ascend tl.load carepadding=False safely to skip initialization of masked tail lanes and remove unnecessary padding work.

Apache-2.0Auto-check passedAI & LLM Engineering

Install Skip Triton Ascend Padding Fill

skills CLI
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill skip-triton-ascend-padding-fill -a claude-code

Project install by default; add -g for ~/.claude/skills/.

GitHub CLI
$ gh skill install Krusty84/triton-ascend-agent-dev-kit skip-triton-ascend-padding-fill --agent claude-code

Project scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).

Manual copy
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/skip-triton-ascend-padding-fill .claude/skills/skip-triton-ascend-padding-fill && rm -rf skills-src

Use ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.

Claude Code skills documentation · loads skills from .claude/skills/

Facts

Skill name
skip-triton-ascend-padding-fill
GitHub stars
106
Token cost
~480 tokens
SKILL.md length
183 words
Files
1
Skills in repo
23
Repo updated
First seen
Licence
Apache-2.0

At a glance

Use Triton-Ascend tl.load carepadding=False safely to skip initialization of masked tail lanes and remove unnecessary padding work.

  • Works in 5 steps: Trace every consumer of the loaded tensor. → Prove that lanes where mask is false… → Omit other and set care_padding=False on… → …
  • An agent profiles a runtime-masked tail load whose invalid lanes are never consumed
  • SKILL.md covers Goal, Workflow, Implementation Pattern and Ascend Guardrails, plus 1 more section
  • Instructions only: no scripts, shell commands, URLs or credentials in SKILL.md

What it does

Skip Triton Ascend Padding Fill is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Use Triton-Ascend tl.load carepadding=False safely to skip initialization of masked tail lanes and remove unnecessary padding work. Use when an agent profiles a runtime-masked tail load whose invalid lanes are never consumed, or needs to decide whether undefined padded values can be permitted for a bandwidth-sensitive Ascend kernel.

Its SKILL.md is about 480 tokens, which your agent loads only when the skill is triggered. It is a single SKILL.md file with no bundled scripts.

It sits in AI & LLM Engineering. The repository describes itself as: A toolkit for AI agents used for development on Triton-Ascend for Ascend NPU. The licence is Apache-2.0.

When your agent uses it

  • An agent profiles a runtime-masked tail load whose invalid lanes are never consumed
  • Needs to decide whether undefined padded values can be permitted for a bandwidth-sensitive Ascend kernel

Example prompts

  • “/skip-triton-ascend-padding-fill”

Requirements

  • Python 3

Workflow steps

5 steps, taken from the first numbered list in SKILL.md.

  1. Trace every consumer of the loaded tensor.
  2. Prove that lanes where mask is false cannot reach arithmetic, reductions, indexing, control flow, or stores.
  3. Omit other and set care_padding=False on the masked load.
  4. Preserve downstream masks until the loaded value is no longer live.
  5. Benchmark against the default padded load on the same runtime-tail shapes.

What it can do on your machine

Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.

  • Tool permissions

    Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.

    From allowed-tools in the SKILL.md frontmatter.

  • Runs code

    No scripts in the folder and no shell commands in SKILL.md (its code samples are python).

    From the folder's file list and the shell code blocks in SKILL.md.

  • Network

    No URLs in SKILL.md.

    From URLs in SKILL.md, links to its own repository left out.

  • Credentials

    Names no API keys, tokens, secrets or passwords.

    From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.

Context cost

Skip Triton Ascend Padding Fill loads about 480 tokens when it runs. Until then it costs about 92 tokens; SKILL.md has 183 words of instructions outside code blocks.

Always · name and description, kept in context so the agent knows when to use it
~92
When it runs · the whole SKILL.md, loaded when a task matches
~480

Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.

Safety

Auto-check passed

The automated check found no risky patterns in SKILL.md.

Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.

SKILL.md

The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 183 words, ~480 tokens.

Download SKILL.mdSave it as .claude/skills/skip-triton-ascend-padding-fill/SKILL.md (or your agent's skills folder).
name
skip-triton-ascend-padding-fill
description
Use Triton-Ascend tl.load care_padding=False safely to skip initialization of masked tail lanes and remove unnecessary padding work. Use when an agent profiles a runtime-masked tail load whose invalid lanes are never consumed, or needs to decide whether undefined padded values can be permitted for a bandwidth-sensitive Ascend kernel.

Skip Triton-Ascend Padding Fill

Goal

Avoid filling invalid load lanes when those values have no influence on any observable result.

Workflow

  1. Trace every consumer of the loaded tensor.
  2. Prove that lanes where mask is false cannot reach arithmetic, reductions, indexing, control flow, or stores.
  3. Omit other and set care_padding=False on the masked load.
  4. Preserve downstream masks until the loaded value is no longer live.
  5. Benchmark against the default padded load on the same runtime-tail shapes.

Implementation Pattern

python
indices = tl.arange(0, BLOCK_SIZE)
mask = indices < runtime_length
values = tl.load(
    input_ptr + indices,
    mask=mask,
    care_padding=False,
)
tl.store(output_ptr + indices, transform(values), mask=mask)

Ascend Guardrails

  • Treat invalid lanes as undefined random values when care_padding=False.
  • Never use this mode before an unmasked reduction, tl.where branch, gather index, dot product, or store.
  • Do not pass other together with care_padding; specifying other restores defined padding behavior.
  • Keep care_padding=True when an algorithm relies on zero, -inf, or another neutral padded value.
  • Expect the optimization to matter mainly for runtime masks; compile-time bounds may already eliminate padding work.

Verification

Compare only valid output lanes with the default implementation and run memory-checking or adversarial tests that make undefined lanes nonzero. Confirm performance on partial tails rather than only full blocks.

© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file

Files

Just SKILL.md in skills/skip-triton-ascend-padding-fill of Krusty84/triton-ascend-agent-dev-kit.

Open the folder on GitHubat commit 4ab5ee7

Compare with similar skills

Skip Triton Ascend Padding Fill next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.

Skip Triton Ascend Padding Fill compared with similar skills
SkillStarsUsed inTokensAuto-checkLicenceRepo updated
Skip Triton Ascend Padding Fill this skillKrusty84/triton-ascend-agent-dev-kit106—~480Automated safety check: PassApache-2.0
Agent BuildershareAI-lab/learn-claude-code78k4 repos~1.2kAutomated safety check: PassMIT
Add Uint Supportpytorch/pytorch104k2 repos~2.3kAutomated safety check: PassCustom licence
LLM Benchmarking with lm-evaluation-harnessOrchestra-Research/AI-Research-SKILLs13k8 repos~3kAutomated safety check: PassMIT
Segment Anything Model GuideOrchestra-Research/AI-Research-SKILLs13k8 repos~3.3kAutomated safety check: PassMIT
1passwordtrpc-group/trpc-agent-go1.9k14 repos~656Automated safety check: PassApache-2.0

Similar skills

  • Agent Builder

    shareAI-lab/learn-claude-code

    Design and build AI agents for any domain. An agent skill from shareAI-lab/learn-claude-code.

    78k GitHub starsUsed in 4 repos~1.2k tokens
    AI & LLM EngineeringAuto-check passed
  • Add Uint Support

    pytorch/pytorch

    Add unsigned integer (uint) type support to PyTorch operators by updating ATDISPATCH macros.

    104k GitHub starsUsed in 2 repos~2.3k tokens
    AI & LLM EngineeringAuto-check passed
  • LLM Benchmarking with lm-evaluation-harness

    Orchestra-Research/AI-Research-SKILLs

    Runs lm-evaluation-harness to benchmark language models on academic suites such as MMLU, GSM8K and HumanEval, compare models and track training checkpoints.

    13k GitHub starsUsed in 8 repos~3k tokens
    AI & LLM EngineeringAuto-check passed
  • Segment Anything Model Guide

    Orchestra-Research/AI-Research-SKILLs

    Guide to using Meta's Segment Anything Model for zero-shot image segmentation with point, box or mask prompts, or automatic mask generation.

    13k GitHub starsUsed in 8 repos~3.3k tokens
    AI & LLM EngineeringAuto-check passed
  • 1password

    trpc-group/trpc-agent-go

    Set up and use 1Password CLI (op). An agent skill from trpc-group/trpc-agent-go.

    1.9k GitHub starsUsed in 14 repos~656 tokens
    AI & LLM EngineeringAuto-check passed
  • Planning With Files

    jarrodwatts/claude-code-config

    Transforms workflow to use Manus-style persistent markdown files for planning, progress tracking, and knowledge storage.

    1.1k GitHub starsUsed in 5 repos~967 tokens
    AI & LLM EngineeringAuto-check passed

More from Krusty84/triton-ascend-agent-dev-kit

All 23 skills in this repo
  • Triton-Ascend Token Pool Assignment

    Krusty84/triton-ascend-agent-dev-kit

    Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.

    106 GitHub stars~564 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Batch Token Reorder

    Krusty84/triton-ascend-agent-dev-kit

    Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.

    106 GitHub stars~597 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Binned MoE Routing

    Krusty84/triton-ascend-agent-dev-kit

    Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.

    106 GitHub stars~662 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Fused Attention

    Krusty84/triton-ascend-agent-dev-kit

    Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.

    106 GitHub stars~753 tokensUpdated 1 mo ago
    Auto-check passed
  • Triton-Ascend Fused Softmax

    Krusty84/triton-ascend-agent-dev-kit

    Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.

    106 GitHub stars~636 tokensUpdated 1 mo ago
    Auto-check passed
  • Build Triton Ascend Layer Norm

    Krusty84/triton-ascend-agent-dev-kit

    Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.

    106 GitHub stars~659 tokensUpdated 1 mo ago
    Auto-check passed

Questions about Skip Triton Ascend Padding Fill

What does Skip Triton Ascend Padding Fill do?

Use Triton-Ascend tl.load carepadding=False safely to skip initialization of masked tail lanes and remove unnecessary padding work. Skip Triton Ascend Padding Fill is an agent skill from Krusty84/triton-ascend-agent-dev-kit.load carepadding=False safely to skip initialization of masked tail lanes and remove unnecessary padding work.

When should I use Skip Triton Ascend Padding Fill?

Skip Triton Ascend Padding Fill fits situations like: an agent profiles a runtime-masked tail load whose invalid lanes are never consumed; needs to decide whether undefined padded values can be permitted for a bandwidth-sensitive Ascend kernel.

How do I install Skip Triton Ascend Padding Fill in Claude Code?

Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill skip-triton-ascend-padding-fill -a claude-code`. Or copy the skill folder (skills/skip-triton-ascend-padding-fill in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/skip-triton-ascend-padding-fill in your project. Claude Code loads it when a task matches its description.

How do I install Skip Triton Ascend Padding Fill in Codex?

Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill skip-triton-ascend-padding-fill -a codex`. Or copy the skill folder (skills/skip-triton-ascend-padding-fill in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/skip-triton-ascend-padding-fill in your project. Codex loads it when a task matches its description.

Can I use Skip Triton Ascend Padding Fill in Cursor, Gemini CLI or GitHub Copilot?

Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill skip-triton-ascend-padding-fill -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/skip-triton-ascend-padding-fill, .gemini/skills/skip-triton-ascend-padding-fill, .github/skills/skip-triton-ascend-padding-fill and .opencode/skills/skip-triton-ascend-padding-fill in your project.

What does Skip Triton Ascend Padding Fill need to run?

SKILL.md names no scripts, command-line tools or credentials: Skip Triton Ascend Padding Fill is instructions for the agent only. Our summary lists: Python 3.

Does Skip Triton Ascend Padding Fill access the network?

SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.

Is Skip Triton Ascend Padding Fill safe to install?

Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.

What licence does Skip Triton Ascend Padding Fill use?

Skip Triton Ascend Padding Fill is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.

How many tokens does Skip Triton Ascend Padding Fill use?

About 480 tokens (SKILL.md is roughly 1.9k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.

What are the alternatives to Skip Triton Ascend Padding Fill?

Skills that share tags, products or a category with Skip Triton Ascend Padding Fill: Agent Builder (shareAI-lab/learn-claude-code, 78k stars), Add Uint Support (pytorch/pytorch, 104k stars), LLM Benchmarking with lm-evaluation-harness (Orchestra-Research/AI-Research-SKILLs, 13k stars) and Segment Anything Model Guide (Orchestra-Research/AI-Research-SKILLs, 13k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.

Who maintains Skip Triton Ascend Padding Fill?

Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.

Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.